@@ -1,6 +1,6 @@
-# from packages import install as install_package
-from web import install_package
 import time
+import subprocess
+import sys
 
 
 def install():
@@ -12,6 +12,11 @@ def install():
     Description:
         required() installs required packages .
     """
+    def install_package(package: str, output: bool = True, version: str = None):
+        new_package = package + "==" + version
+        subprocess.check_call([sys.executable, "-m", "pip", "install", new_package])
+        if output:
+            print(f"Library {package}({version}) installed.")
 
     require = ["requests", "ipython", "dearpygui"]
     versions = ["2.28.1", "8.5.0", "1.7.1"]
